# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/objectstored/v1/objectstored.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/objectstored/v1/objectstored.proto',
  package='github.com.metaprov.modelaapi.services.objectstored.v1',
  syntax='proto3',
  serialized_options=b'Z6github.com/metaprov/modelaapi/services/objectstored/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nIgithub.com/metaprov/modelaapi/services/objectstored/v1/objectstored.proto\x12\x36github.com.metaprov.modelaapi.services.objectstored.v1\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\"!\n\x0eIngestResponse\x12\x0f\n\x07liveKey\x18\x01 \x01(\t\"%\n\x0eObjectResponse\x12\x13\n\x0b\x61rchivePath\x18\x01 \x01(\t\"\xdb\x02\n\rObjectRequest\x12T\n\x06\x62ucket\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x61\n\x06secret\x18\x06 \x03(\x0b\x32Q.github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest.SecretEntry\x12\x0b\n\x03key\x18\x07 \x01(\t\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"-\n\x1c\x45xistInVirtualBucketResponse\x12\r\n\x05\x65xist\x18\x01 \x01(\x08\x32\xa2\x05\n\x12ObjectstoreService\x12\x99\x01\n\x06Ingest\x12\x45.github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest\x1a\x46.github.com.metaprov.modelaapi.services.objectstored.v1.ObjectResponse\"\x00\x12\x9a\x01\n\x07\x41rchive\x12\x45.github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest\x1a\x46.github.com.metaprov.modelaapi.services.objectstored.v1.ObjectResponse\"\x00\x12\x9a\x01\n\x07Recover\x12\x45.github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest\x1a\x46.github.com.metaprov.modelaapi.services.objectstored.v1.ObjectResponse\"\x00\x12\xb5\x01\n\x14\x45xistInVirtualBucket\x12\x45.github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest\x1aT.github.com.metaprov.modelaapi.services.objectstored.v1.ExistInVirtualBucketResponse\"\x00\x42\x38Z6github.com/metaprov/modelaapi/services/objectstored/v1b\x06proto3'
  ,
  dependencies=[github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_INGESTRESPONSE = _descriptor.Descriptor(
  name='IngestResponse',
  full_name='github.com.metaprov.modelaapi.services.objectstored.v1.IngestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='liveKey', full_name='github.com.metaprov.modelaapi.services.objectstored.v1.IngestResponse.liveKey', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=204,
  serialized_end=237,
)


_OBJECTRESPONSE = _descriptor.Descriptor(
  name='ObjectResponse',
  full_name='github.com.metaprov.modelaapi.services.objectstored.v1.ObjectResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='archivePath', full_name='github.com.metaprov.modelaapi.services.objectstored.v1.ObjectResponse.archivePath', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=239,
  serialized_end=276,
)


_OBJECTREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=581,
  serialized_end=626,
)

_OBJECTREQUEST = _descriptor.Descriptor(
  name='ObjectRequest',
  full_name='github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest.bucket', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest.connection', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest.secret', index=2,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest.key', index=3,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_OBJECTREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=279,
  serialized_end=626,
)


_EXISTINVIRTUALBUCKETRESPONSE = _descriptor.Descriptor(
  name='ExistInVirtualBucketResponse',
  full_name='github.com.metaprov.modelaapi.services.objectstored.v1.ExistInVirtualBucketResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='exist', full_name='github.com.metaprov.modelaapi.services.objectstored.v1.ExistInVirtualBucketResponse.exist', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=628,
  serialized_end=673,
)

_OBJECTREQUEST_SECRETENTRY.containing_type = _OBJECTREQUEST
_OBJECTREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_OBJECTREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_OBJECTREQUEST.fields_by_name['secret'].message_type = _OBJECTREQUEST_SECRETENTRY
DESCRIPTOR.message_types_by_name['IngestResponse'] = _INGESTRESPONSE
DESCRIPTOR.message_types_by_name['ObjectResponse'] = _OBJECTRESPONSE
DESCRIPTOR.message_types_by_name['ObjectRequest'] = _OBJECTREQUEST
DESCRIPTOR.message_types_by_name['ExistInVirtualBucketResponse'] = _EXISTINVIRTUALBUCKETRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

IngestResponse = _reflection.GeneratedProtocolMessageType('IngestResponse', (_message.Message,), {
  'DESCRIPTOR' : _INGESTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.objectstored.v1.objectstored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.objectstored.v1.IngestResponse)
  })
_sym_db.RegisterMessage(IngestResponse)

ObjectResponse = _reflection.GeneratedProtocolMessageType('ObjectResponse', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.objectstored.v1.objectstored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.objectstored.v1.ObjectResponse)
  })
_sym_db.RegisterMessage(ObjectResponse)

ObjectRequest = _reflection.GeneratedProtocolMessageType('ObjectRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _OBJECTREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.objectstored.v1.objectstored_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _OBJECTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.objectstored.v1.objectstored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest)
  })
_sym_db.RegisterMessage(ObjectRequest)
_sym_db.RegisterMessage(ObjectRequest.SecretEntry)

ExistInVirtualBucketResponse = _reflection.GeneratedProtocolMessageType('ExistInVirtualBucketResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXISTINVIRTUALBUCKETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.objectstored.v1.objectstored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.objectstored.v1.ExistInVirtualBucketResponse)
  })
_sym_db.RegisterMessage(ExistInVirtualBucketResponse)


DESCRIPTOR._options = None
_OBJECTREQUEST_SECRETENTRY._options = None

_OBJECTSTORESERVICE = _descriptor.ServiceDescriptor(
  name='ObjectstoreService',
  full_name='github.com.metaprov.modelaapi.services.objectstored.v1.ObjectstoreService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=676,
  serialized_end=1350,
  methods=[
  _descriptor.MethodDescriptor(
    name='Ingest',
    full_name='github.com.metaprov.modelaapi.services.objectstored.v1.ObjectstoreService.Ingest',
    index=0,
    containing_service=None,
    input_type=_OBJECTREQUEST,
    output_type=_OBJECTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Archive',
    full_name='github.com.metaprov.modelaapi.services.objectstored.v1.ObjectstoreService.Archive',
    index=1,
    containing_service=None,
    input_type=_OBJECTREQUEST,
    output_type=_OBJECTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Recover',
    full_name='github.com.metaprov.modelaapi.services.objectstored.v1.ObjectstoreService.Recover',
    index=2,
    containing_service=None,
    input_type=_OBJECTREQUEST,
    output_type=_OBJECTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ExistInVirtualBucket',
    full_name='github.com.metaprov.modelaapi.services.objectstored.v1.ObjectstoreService.ExistInVirtualBucket',
    index=3,
    containing_service=None,
    input_type=_OBJECTREQUEST,
    output_type=_EXISTINVIRTUALBUCKETRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_OBJECTSTORESERVICE)

DESCRIPTOR.services_by_name['ObjectstoreService'] = _OBJECTSTORESERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/modelpipeline/v1/modelpipeline.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/modelpipeline/v1/modelpipeline.proto',
  package='github.com.metaprov.modelaapi.services.modelpipeline.v1',
  syntax='proto3',
  serialized_options=b'Z7github.com/metaprov/modelaapi/services/modelpipeline/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nKgithub.com/metaprov/modelaapi/services/modelpipeline/v1/modelpipeline.proto\x12\x37github.com.metaprov.modelaapi.services.modelpipeline.v1\x1a\x1cgoogle/api/annotations.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\"\xcd\x01\n\x19ListModelPipelinesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12n\n\x06labels\x18\x03 \x03(\x0b\x32^.github.com.metaprov.modelaapi.services.modelpipeline.v1.ListModelPipelinesRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"x\n\x1aListModelPipelinesResponse\x12Z\n\x05items\x18\x01 \x01(\x0b\x32K.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineList\"\x17\n\x15ModelPipelineResponse\"s\n\x1a\x43reateModelPipelineRequest\x12U\n\x04item\x18\x01 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipeline\"\x1d\n\x1b\x43reateModelPipelineResponse\"s\n\x1aUpdateModelPipelineRequest\x12U\n\x04item\x18\x01 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipeline\"\x1d\n\x1bUpdateModelPipelineResponse\":\n\x17GetModelPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x7f\n\x18GetModelPipelineResponse\x12U\n\x04item\x18\x01 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipeline\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"=\n\x1a\x44\x65leteModelPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1d\n\x1b\x44\x65leteModelPipelineResponse\"p\n\x17RunModelPipelineRequest\x12U\n\x04item\x18\x01 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipeline\"\x1a\n\x18RunModelPipelineResponse\"\x1c\n\x1aPauseModelPipelineResponse\"<\n\x19PauseModelPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1d\n\x1bResumeModelPipelineResponse\"=\n\x1aResumeModelPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t2\xa1\x0f\n\x14ModelPipelineService\x12\xe3\x01\n\x12ListModelPipelines\x12R.github.com.metaprov.modelaapi.services.modelpipeline.v1.ListModelPipelinesRequest\x1aS.github.com.metaprov.modelaapi.services.modelpipeline.v1.ListModelPipelinesResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/api/v1alpha1/modelpipelines\x12\xe9\x01\n\x13\x43reateModelPipeline\x12S.github.com.metaprov.modelaapi.services.modelpipeline.v1.CreateModelPipelineRequest\x1aT.github.com.metaprov.modelaapi.services.modelpipeline.v1.CreateModelPipelineResponse\"\'\x82\xd3\xe4\x93\x02!\"\x1c/api/v1alpha1/modelpipelines:\x01*\x12\xe4\x01\n\x10GetModelPipeline\x12P.github.com.metaprov.modelaapi.services.modelpipeline.v1.GetModelPipelineRequest\x1aQ.github.com.metaprov.modelaapi.services.modelpipeline.v1.GetModelPipelineResponse\"+\x82\xd3\xe4\x93\x02%\x12#/api/v1alpha1/modelpipelines/{name}\x12\x87\x02\n\x13UpdateModelPipeline\x12S.github.com.metaprov.modelaapi.services.modelpipeline.v1.UpdateModelPipelineRequest\x1aT.github.com.metaprov.modelaapi.services.modelpipeline.v1.UpdateModelPipelineResponse\"E\x82\xd3\xe4\x93\x02?\x1a:/api/v1alpha1/modelpipelines/{modelpipeline.metadata.name}:\x01*\x12\xfe\x01\n\x13\x44\x65leteModelPipeline\x12S.github.com.metaprov.modelaapi.services.modelpipeline.v1.DeleteModelPipelineRequest\x1aT.github.com.metaprov.modelaapi.services.modelpipeline.v1.DeleteModelPipelineResponse\"<\x82\xd3\xe4\x93\x02\x36*4/api/v1/modelpipelines/{modelpipeline.metadata.name}\x12\xee\x01\n\x10RunModelPipeline\x12P.github.com.metaprov.modelaapi.services.modelpipeline.v1.RunModelPipelineRequest\x1aQ.github.com.metaprov.modelaapi.services.modelpipeline.v1.RunModelPipelineResponse\"5\x82\xd3\xe4\x93\x02/\"-/api/v1/modelpipelines/{namespace}/{name}:run\x12\xe6\x01\n\x12PauseModelPipeline\x12R.github.com.metaprov.modelaapi.services.modelpipeline.v1.PauseModelPipelineRequest\x1aS.github.com.metaprov.modelaapi.services.modelpipeline.v1.PauseModelPipelineResponse\"\'\x82\xd3\xe4\x93\x02!\"\x1f/v1/modelpipelines/{name}:pause\x12\xea\x01\n\x13ResumeModelPipeline\x12S.github.com.metaprov.modelaapi.services.modelpipeline.v1.ResumeModelPipelineRequest\x1aT.github.com.metaprov.modelaapi.services.modelpipeline.v1.ResumeModelPipelineResponse\"(\x82\xd3\xe4\x93\x02\"\" /v1/modelpipelines/{name}:resumeB9Z7github.com/metaprov/modelaapi/services/modelpipeline/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTMODELPIPELINESREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.ListModelPipelinesRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.ListModelPipelinesRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.ListModelPipelinesRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=401,
  serialized_end=446,
)

_LISTMODELPIPELINESREQUEST = _descriptor.Descriptor(
  name='ListModelPipelinesRequest',
  full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.ListModelPipelinesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.ListModelPipelinesRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.ListModelPipelinesRequest.labels', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTMODELPIPELINESREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=241,
  serialized_end=446,
)


_LISTMODELPIPELINESRESPONSE = _descriptor.Descriptor(
  name='ListModelPipelinesResponse',
  full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.ListModelPipelinesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.ListModelPipelinesResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=448,
  serialized_end=568,
)


_MODELPIPELINERESPONSE = _descriptor.Descriptor(
  name='ModelPipelineResponse',
  full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.ModelPipelineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=570,
  serialized_end=593,
)


_CREATEMODELPIPELINEREQUEST = _descriptor.Descriptor(
  name='CreateModelPipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.CreateModelPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.CreateModelPipelineRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=595,
  serialized_end=710,
)


_CREATEMODELPIPELINERESPONSE = _descriptor.Descriptor(
  name='CreateModelPipelineResponse',
  full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.CreateModelPipelineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=712,
  serialized_end=741,
)


_UPDATEMODELPIPELINEREQUEST = _descriptor.Descriptor(
  name='UpdateModelPipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.UpdateModelPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.UpdateModelPipelineRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=743,
  serialized_end=858,
)


_UPDATEMODELPIPELINERESPONSE = _descriptor.Descriptor(
  name='UpdateModelPipelineResponse',
  full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.UpdateModelPipelineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=860,
  serialized_end=889,
)


_GETMODELPIPELINEREQUEST = _descriptor.Descriptor(
  name='GetModelPipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.GetModelPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.GetModelPipelineRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.GetModelPipelineRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=891,
  serialized_end=949,
)


_GETMODELPIPELINERESPONSE = _descriptor.Descriptor(
  name='GetModelPipelineResponse',
  full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.GetModelPipelineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.GetModelPipelineResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.GetModelPipelineResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=951,
  serialized_end=1078,
)


_DELETEMODELPIPELINEREQUEST = _descriptor.Descriptor(
  name='DeleteModelPipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.DeleteModelPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.DeleteModelPipelineRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.DeleteModelPipelineRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1080,
  serialized_end=1141,
)


_DELETEMODELPIPELINERESPONSE = _descriptor.Descriptor(
  name='DeleteModelPipelineResponse',
  full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.DeleteModelPipelineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1143,
  serialized_end=1172,
)


_RUNMODELPIPELINEREQUEST = _descriptor.Descriptor(
  name='RunModelPipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.RunModelPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.RunModelPipelineRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1174,
  serialized_end=1286,
)


_RUNMODELPIPELINERESPONSE = _descriptor.Descriptor(
  name='RunModelPipelineResponse',
  full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.RunModelPipelineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1288,
  serialized_end=1314,
)


_PAUSEMODELPIPELINERESPONSE = _descriptor.Descriptor(
  name='PauseModelPipelineResponse',
  full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.PauseModelPipelineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1316,
  serialized_end=1344,
)


_PAUSEMODELPIPELINEREQUEST = _descriptor.Descriptor(
  name='PauseModelPipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.PauseModelPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.PauseModelPipelineRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.PauseModelPipelineRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1346,
  serialized_end=1406,
)


_RESUMEMODELPIPELINERESPONSE = _descriptor.Descriptor(
  name='ResumeModelPipelineResponse',
  full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.ResumeModelPipelineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1408,
  serialized_end=1437,
)


_RESUMEMODELPIPELINEREQUEST = _descriptor.Descriptor(
  name='ResumeModelPipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.ResumeModelPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.ResumeModelPipelineRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.ResumeModelPipelineRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1439,
  serialized_end=1500,
)

_LISTMODELPIPELINESREQUEST_LABELSENTRY.containing_type = _LISTMODELPIPELINESREQUEST
_LISTMODELPIPELINESREQUEST.fields_by_name['labels'].message_type = _LISTMODELPIPELINESREQUEST_LABELSENTRY
_LISTMODELPIPELINESRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELPIPELINELIST
_CREATEMODELPIPELINEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELPIPELINE
_UPDATEMODELPIPELINEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELPIPELINE
_GETMODELPIPELINERESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELPIPELINE
_RUNMODELPIPELINEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELPIPELINE
DESCRIPTOR.message_types_by_name['ListModelPipelinesRequest'] = _LISTMODELPIPELINESREQUEST
DESCRIPTOR.message_types_by_name['ListModelPipelinesResponse'] = _LISTMODELPIPELINESRESPONSE
DESCRIPTOR.message_types_by_name['ModelPipelineResponse'] = _MODELPIPELINERESPONSE
DESCRIPTOR.message_types_by_name['CreateModelPipelineRequest'] = _CREATEMODELPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['CreateModelPipelineResponse'] = _CREATEMODELPIPELINERESPONSE
DESCRIPTOR.message_types_by_name['UpdateModelPipelineRequest'] = _UPDATEMODELPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['UpdateModelPipelineResponse'] = _UPDATEMODELPIPELINERESPONSE
DESCRIPTOR.message_types_by_name['GetModelPipelineRequest'] = _GETMODELPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['GetModelPipelineResponse'] = _GETMODELPIPELINERESPONSE
DESCRIPTOR.message_types_by_name['DeleteModelPipelineRequest'] = _DELETEMODELPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['DeleteModelPipelineResponse'] = _DELETEMODELPIPELINERESPONSE
DESCRIPTOR.message_types_by_name['RunModelPipelineRequest'] = _RUNMODELPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['RunModelPipelineResponse'] = _RUNMODELPIPELINERESPONSE
DESCRIPTOR.message_types_by_name['PauseModelPipelineResponse'] = _PAUSEMODELPIPELINERESPONSE
DESCRIPTOR.message_types_by_name['PauseModelPipelineRequest'] = _PAUSEMODELPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['ResumeModelPipelineResponse'] = _RESUMEMODELPIPELINERESPONSE
DESCRIPTOR.message_types_by_name['ResumeModelPipelineRequest'] = _RESUMEMODELPIPELINEREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListModelPipelinesRequest = _reflection.GeneratedProtocolMessageType('ListModelPipelinesRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTMODELPIPELINESREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.ListModelPipelinesRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTMODELPIPELINESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.ListModelPipelinesRequest)
  })
_sym_db.RegisterMessage(ListModelPipelinesRequest)
_sym_db.RegisterMessage(ListModelPipelinesRequest.LabelsEntry)

ListModelPipelinesResponse = _reflection.GeneratedProtocolMessageType('ListModelPipelinesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELPIPELINESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.ListModelPipelinesResponse)
  })
_sym_db.RegisterMessage(ListModelPipelinesResponse)

ModelPipelineResponse = _reflection.GeneratedProtocolMessageType('ModelPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _MODELPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.ModelPipelineResponse)
  })
_sym_db.RegisterMessage(ModelPipelineResponse)

CreateModelPipelineRequest = _reflection.GeneratedProtocolMessageType('CreateModelPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.CreateModelPipelineRequest)
  })
_sym_db.RegisterMessage(CreateModelPipelineRequest)

CreateModelPipelineResponse = _reflection.GeneratedProtocolMessageType('CreateModelPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.CreateModelPipelineResponse)
  })
_sym_db.RegisterMessage(CreateModelPipelineResponse)

UpdateModelPipelineRequest = _reflection.GeneratedProtocolMessageType('UpdateModelPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.UpdateModelPipelineRequest)
  })
_sym_db.RegisterMessage(UpdateModelPipelineRequest)

UpdateModelPipelineResponse = _reflection.GeneratedProtocolMessageType('UpdateModelPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.UpdateModelPipelineResponse)
  })
_sym_db.RegisterMessage(UpdateModelPipelineResponse)

GetModelPipelineRequest = _reflection.GeneratedProtocolMessageType('GetModelPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.GetModelPipelineRequest)
  })
_sym_db.RegisterMessage(GetModelPipelineRequest)

GetModelPipelineResponse = _reflection.GeneratedProtocolMessageType('GetModelPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.GetModelPipelineResponse)
  })
_sym_db.RegisterMessage(GetModelPipelineResponse)

DeleteModelPipelineRequest = _reflection.GeneratedProtocolMessageType('DeleteModelPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.DeleteModelPipelineRequest)
  })
_sym_db.RegisterMessage(DeleteModelPipelineRequest)

DeleteModelPipelineResponse = _reflection.GeneratedProtocolMessageType('DeleteModelPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.DeleteModelPipelineResponse)
  })
_sym_db.RegisterMessage(DeleteModelPipelineResponse)

RunModelPipelineRequest = _reflection.GeneratedProtocolMessageType('RunModelPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNMODELPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.RunModelPipelineRequest)
  })
_sym_db.RegisterMessage(RunModelPipelineRequest)

RunModelPipelineResponse = _reflection.GeneratedProtocolMessageType('RunModelPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNMODELPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.RunModelPipelineResponse)
  })
_sym_db.RegisterMessage(RunModelPipelineResponse)

PauseModelPipelineResponse = _reflection.GeneratedProtocolMessageType('PauseModelPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEMODELPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.PauseModelPipelineResponse)
  })
_sym_db.RegisterMessage(PauseModelPipelineResponse)

PauseModelPipelineRequest = _reflection.GeneratedProtocolMessageType('PauseModelPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEMODELPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.PauseModelPipelineRequest)
  })
_sym_db.RegisterMessage(PauseModelPipelineRequest)

ResumeModelPipelineResponse = _reflection.GeneratedProtocolMessageType('ResumeModelPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEMODELPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.ResumeModelPipelineResponse)
  })
_sym_db.RegisterMessage(ResumeModelPipelineResponse)

ResumeModelPipelineRequest = _reflection.GeneratedProtocolMessageType('ResumeModelPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEMODELPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipeline.v1.modelpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipeline.v1.ResumeModelPipelineRequest)
  })
_sym_db.RegisterMessage(ResumeModelPipelineRequest)


DESCRIPTOR._options = None
_LISTMODELPIPELINESREQUEST_LABELSENTRY._options = None

_MODELPIPELINESERVICE = _descriptor.ServiceDescriptor(
  name='ModelPipelineService',
  full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.ModelPipelineService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1503,
  serialized_end=3456,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListModelPipelines',
    full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.ModelPipelineService.ListModelPipelines',
    index=0,
    containing_service=None,
    input_type=_LISTMODELPIPELINESREQUEST,
    output_type=_LISTMODELPIPELINESRESPONSE,
    serialized_options=b'\202\323\344\223\002\036\022\034/api/v1alpha1/modelpipelines',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateModelPipeline',
    full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.ModelPipelineService.CreateModelPipeline',
    index=1,
    containing_service=None,
    input_type=_CREATEMODELPIPELINEREQUEST,
    output_type=_CREATEMODELPIPELINERESPONSE,
    serialized_options=b'\202\323\344\223\002!\"\034/api/v1alpha1/modelpipelines:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetModelPipeline',
    full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.ModelPipelineService.GetModelPipeline',
    index=2,
    containing_service=None,
    input_type=_GETMODELPIPELINEREQUEST,
    output_type=_GETMODELPIPELINERESPONSE,
    serialized_options=b'\202\323\344\223\002%\022#/api/v1alpha1/modelpipelines/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateModelPipeline',
    full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.ModelPipelineService.UpdateModelPipeline',
    index=3,
    containing_service=None,
    input_type=_UPDATEMODELPIPELINEREQUEST,
    output_type=_UPDATEMODELPIPELINERESPONSE,
    serialized_options=b'\202\323\344\223\002?\032:/api/v1alpha1/modelpipelines/{modelpipeline.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteModelPipeline',
    full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.ModelPipelineService.DeleteModelPipeline',
    index=4,
    containing_service=None,
    input_type=_DELETEMODELPIPELINEREQUEST,
    output_type=_DELETEMODELPIPELINERESPONSE,
    serialized_options=b'\202\323\344\223\0026*4/api/v1/modelpipelines/{modelpipeline.metadata.name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RunModelPipeline',
    full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.ModelPipelineService.RunModelPipeline',
    index=5,
    containing_service=None,
    input_type=_RUNMODELPIPELINEREQUEST,
    output_type=_RUNMODELPIPELINERESPONSE,
    serialized_options=b'\202\323\344\223\002/\"-/api/v1/modelpipelines/{namespace}/{name}:run',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PauseModelPipeline',
    full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.ModelPipelineService.PauseModelPipeline',
    index=6,
    containing_service=None,
    input_type=_PAUSEMODELPIPELINEREQUEST,
    output_type=_PAUSEMODELPIPELINERESPONSE,
    serialized_options=b'\202\323\344\223\002!\"\037/v1/modelpipelines/{name}:pause',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResumeModelPipeline',
    full_name='github.com.metaprov.modelaapi.services.modelpipeline.v1.ModelPipelineService.ResumeModelPipeline',
    index=7,
    containing_service=None,
    input_type=_RESUMEMODELPIPELINEREQUEST,
    output_type=_RESUMEMODELPIPELINERESPONSE,
    serialized_options=b'\202\323\344\223\002\"\" /v1/modelpipelines/{name}:resume',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MODELPIPELINESERVICE)

DESCRIPTOR.services_by_name['ModelPipelineService'] = _MODELPIPELINESERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/featurehistogram/v1/featurehistogram.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/featurehistogram/v1/featurehistogram.proto',
  package='github.com.metaprov.modelaapi.services.featurehistogram.v1',
  syntax='proto3',
  serialized_options=b'Z:github.com/metaprov/modelaapi/services/featurehistogram/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nQgithub.com/metaprov/modelaapi/services/featurehistogram/v1/featurehistogram.proto\x12:github.com.metaprov.modelaapi.services.featurehistogram.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xd6\x01\n\x1cListFeatureHistogramsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12t\n\x06labels\x18\x02 \x03(\x0b\x32\x64.github.com.metaprov.modelaapi.services.featurehistogram.v1.ListFeatureHistogramsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"z\n\x1dListFeatureHistogramsResponse\x12Y\n\x05items\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogramList\"u\n\x1d\x43reateFeatureHistogramRequest\x12T\n\x04item\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogram\" \n\x1e\x43reateFeatureHistogramResponse\"u\n\x1dUpdateFeatureHistogramRequest\x12T\n\x04item\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogram\" \n\x1eUpdateFeatureHistogramResponse\"=\n\x1aGetFeatureHistogramRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x81\x01\n\x1bGetFeatureHistogramResponse\x12T\n\x04item\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureHistogram\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"@\n\x1d\x44\x65leteFeatureHistogramRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\" \n\x1e\x44\x65leteFeatureHistogramResponse2\xd3\t\n\x17\x46\x65\x61tureHistogramService\x12\xeb\x01\n\x15ListFeatureHistograms\x12X.github.com.metaprov.modelaapi.services.featurehistogram.v1.ListFeatureHistogramsRequest\x1aY.github.com.metaprov.modelaapi.services.featurehistogram.v1.ListFeatureHistogramsResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/featurehistograms\x12\xf1\x01\n\x16\x43reateFeatureHistogram\x12Y.github.com.metaprov.modelaapi.services.featurehistogram.v1.CreateFeatureHistogramRequest\x1aZ.github.com.metaprov.modelaapi.services.featurehistogram.v1.CreateFeatureHistogramResponse\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v1/featurehistograms:\x01*\x12\xec\x01\n\x13GetFeatureHistogram\x12V.github.com.metaprov.modelaapi.services.featurehistogram.v1.GetFeatureHistogramRequest\x1aW.github.com.metaprov.modelaapi.services.featurehistogram.v1.GetFeatureHistogramResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1/featurehistograms/{name}\x12\x92\x02\n\x16UpdateFeatureHistogram\x12Y.github.com.metaprov.modelaapi.services.featurehistogram.v1.UpdateFeatureHistogramRequest\x1aZ.github.com.metaprov.modelaapi.services.featurehistogram.v1.UpdateFeatureHistogramResponse\"A\x82\xd3\xe4\x93\x02;\x1a\x36/v1/featurehistograms/{featurehistogram.metadata.name}:\x01*\x12\xd1\x01\n\x16\x44\x65leteFeatureHistogram\x12Y.github.com.metaprov.modelaapi.services.featurehistogram.v1.DeleteFeatureHistogramRequest\x1aZ.github.com.metaprov.modelaapi.services.featurehistogram.v1.DeleteFeatureHistogramResponse\"\x00\x42<Z:github.com/metaprov/modelaapi/services/featurehistogram/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTFEATUREHISTOGRAMSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.featurehistogram.v1.ListFeatureHistogramsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.featurehistogram.v1.ListFeatureHistogramsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.featurehistogram.v1.ListFeatureHistogramsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=415,
  serialized_end=460,
)

_LISTFEATUREHISTOGRAMSREQUEST = _descriptor.Descriptor(
  name='ListFeatureHistogramsRequest',
  full_name='github.com.metaprov.modelaapi.services.featurehistogram.v1.ListFeatureHistogramsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.featurehistogram.v1.ListFeatureHistogramsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.featurehistogram.v1.ListFeatureHistogramsRequest.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTFEATUREHISTOGRAMSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=246,
  serialized_end=460,
)


_LISTFEATUREHISTOGRAMSRESPONSE = _descriptor.Descriptor(
  name='ListFeatureHistogramsResponse',
  full_name='github.com.metaprov.modelaapi.services.featurehistogram.v1.ListFeatureHistogramsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.featurehistogram.v1.ListFeatureHistogramsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=462,
  serialized_end=584,
)


_CREATEFEATUREHISTOGRAMREQUEST = _descriptor.Descriptor(
  name='CreateFeatureHistogramRequest',
  full_name='github.com.metaprov.modelaapi.services.featurehistogram.v1.CreateFeatureHistogramRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.featurehistogram.v1.CreateFeatureHistogramRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=586,
  serialized_end=703,
)


_CREATEFEATUREHISTOGRAMRESPONSE = _descriptor.Descriptor(
  name='CreateFeatureHistogramResponse',
  full_name='github.com.metaprov.modelaapi.services.featurehistogram.v1.CreateFeatureHistogramResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=705,
  serialized_end=737,
)


_UPDATEFEATUREHISTOGRAMREQUEST = _descriptor.Descriptor(
  name='UpdateFeatureHistogramRequest',
  full_name='github.com.metaprov.modelaapi.services.featurehistogram.v1.UpdateFeatureHistogramRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.featurehistogram.v1.UpdateFeatureHistogramRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=739,
  serialized_end=856,
)


_UPDATEFEATUREHISTOGRAMRESPONSE = _descriptor.Descriptor(
  name='UpdateFeatureHistogramResponse',
  full_name='github.com.metaprov.modelaapi.services.featurehistogram.v1.UpdateFeatureHistogramResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=858,
  serialized_end=890,
)


_GETFEATUREHISTOGRAMREQUEST = _descriptor.Descriptor(
  name='GetFeatureHistogramRequest',
  full_name='github.com.metaprov.modelaapi.services.featurehistogram.v1.GetFeatureHistogramRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.featurehistogram.v1.GetFeatureHistogramRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.featurehistogram.v1.GetFeatureHistogramRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=892,
  serialized_end=953,
)


_GETFEATUREHISTOGRAMRESPONSE = _descriptor.Descriptor(
  name='GetFeatureHistogramResponse',
  full_name='github.com.metaprov.modelaapi.services.featurehistogram.v1.GetFeatureHistogramResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.featurehistogram.v1.GetFeatureHistogramResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.featurehistogram.v1.GetFeatureHistogramResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=956,
  serialized_end=1085,
)


_DELETEFEATUREHISTOGRAMREQUEST = _descriptor.Descriptor(
  name='DeleteFeatureHistogramRequest',
  full_name='github.com.metaprov.modelaapi.services.featurehistogram.v1.DeleteFeatureHistogramRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.featurehistogram.v1.DeleteFeatureHistogramRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.featurehistogram.v1.DeleteFeatureHistogramRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1087,
  serialized_end=1151,
)


_DELETEFEATUREHISTOGRAMRESPONSE = _descriptor.Descriptor(
  name='DeleteFeatureHistogramResponse',
  full_name='github.com.metaprov.modelaapi.services.featurehistogram.v1.DeleteFeatureHistogramResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1153,
  serialized_end=1185,
)

_LISTFEATUREHISTOGRAMSREQUEST_LABELSENTRY.containing_type = _LISTFEATUREHISTOGRAMSREQUEST
_LISTFEATUREHISTOGRAMSREQUEST.fields_by_name['labels'].message_type = _LISTFEATUREHISTOGRAMSREQUEST_LABELSENTRY
_LISTFEATUREHISTOGRAMSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATUREHISTOGRAMLIST
_CREATEFEATUREHISTOGRAMREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATUREHISTOGRAM
_UPDATEFEATUREHISTOGRAMREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATUREHISTOGRAM
_GETFEATUREHISTOGRAMRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATUREHISTOGRAM
DESCRIPTOR.message_types_by_name['ListFeatureHistogramsRequest'] = _LISTFEATUREHISTOGRAMSREQUEST
DESCRIPTOR.message_types_by_name['ListFeatureHistogramsResponse'] = _LISTFEATUREHISTOGRAMSRESPONSE
DESCRIPTOR.message_types_by_name['CreateFeatureHistogramRequest'] = _CREATEFEATUREHISTOGRAMREQUEST
DESCRIPTOR.message_types_by_name['CreateFeatureHistogramResponse'] = _CREATEFEATUREHISTOGRAMRESPONSE
DESCRIPTOR.message_types_by_name['UpdateFeatureHistogramRequest'] = _UPDATEFEATUREHISTOGRAMREQUEST
DESCRIPTOR.message_types_by_name['UpdateFeatureHistogramResponse'] = _UPDATEFEATUREHISTOGRAMRESPONSE
DESCRIPTOR.message_types_by_name['GetFeatureHistogramRequest'] = _GETFEATUREHISTOGRAMREQUEST
DESCRIPTOR.message_types_by_name['GetFeatureHistogramResponse'] = _GETFEATUREHISTOGRAMRESPONSE
DESCRIPTOR.message_types_by_name['DeleteFeatureHistogramRequest'] = _DELETEFEATUREHISTOGRAMREQUEST
DESCRIPTOR.message_types_by_name['DeleteFeatureHistogramResponse'] = _DELETEFEATUREHISTOGRAMRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListFeatureHistogramsRequest = _reflection.GeneratedProtocolMessageType('ListFeatureHistogramsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTFEATUREHISTOGRAMSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.featurehistogram.v1.featurehistogram_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurehistogram.v1.ListFeatureHistogramsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTFEATUREHISTOGRAMSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurehistogram.v1.featurehistogram_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurehistogram.v1.ListFeatureHistogramsRequest)
  })
_sym_db.RegisterMessage(ListFeatureHistogramsRequest)
_sym_db.RegisterMessage(ListFeatureHistogramsRequest.LabelsEntry)

ListFeatureHistogramsResponse = _reflection.GeneratedProtocolMessageType('ListFeatureHistogramsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATUREHISTOGRAMSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurehistogram.v1.featurehistogram_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurehistogram.v1.ListFeatureHistogramsResponse)
  })
_sym_db.RegisterMessage(ListFeatureHistogramsResponse)

CreateFeatureHistogramRequest = _reflection.GeneratedProtocolMessageType('CreateFeatureHistogramRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATUREHISTOGRAMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurehistogram.v1.featurehistogram_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurehistogram.v1.CreateFeatureHistogramRequest)
  })
_sym_db.RegisterMessage(CreateFeatureHistogramRequest)

CreateFeatureHistogramResponse = _reflection.GeneratedProtocolMessageType('CreateFeatureHistogramResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATUREHISTOGRAMRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurehistogram.v1.featurehistogram_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurehistogram.v1.CreateFeatureHistogramResponse)
  })
_sym_db.RegisterMessage(CreateFeatureHistogramResponse)

UpdateFeatureHistogramRequest = _reflection.GeneratedProtocolMessageType('UpdateFeatureHistogramRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREHISTOGRAMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurehistogram.v1.featurehistogram_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurehistogram.v1.UpdateFeatureHistogramRequest)
  })
_sym_db.RegisterMessage(UpdateFeatureHistogramRequest)

UpdateFeatureHistogramResponse = _reflection.GeneratedProtocolMessageType('UpdateFeatureHistogramResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREHISTOGRAMRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurehistogram.v1.featurehistogram_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurehistogram.v1.UpdateFeatureHistogramResponse)
  })
_sym_db.RegisterMessage(UpdateFeatureHistogramResponse)

GetFeatureHistogramRequest = _reflection.GeneratedProtocolMessageType('GetFeatureHistogramRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREHISTOGRAMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurehistogram.v1.featurehistogram_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurehistogram.v1.GetFeatureHistogramRequest)
  })
_sym_db.RegisterMessage(GetFeatureHistogramRequest)

GetFeatureHistogramResponse = _reflection.GeneratedProtocolMessageType('GetFeatureHistogramResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREHISTOGRAMRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurehistogram.v1.featurehistogram_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurehistogram.v1.GetFeatureHistogramResponse)
  })
_sym_db.RegisterMessage(GetFeatureHistogramResponse)

DeleteFeatureHistogramRequest = _reflection.GeneratedProtocolMessageType('DeleteFeatureHistogramRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREHISTOGRAMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurehistogram.v1.featurehistogram_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurehistogram.v1.DeleteFeatureHistogramRequest)
  })
_sym_db.RegisterMessage(DeleteFeatureHistogramRequest)

DeleteFeatureHistogramResponse = _reflection.GeneratedProtocolMessageType('DeleteFeatureHistogramResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREHISTOGRAMRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurehistogram.v1.featurehistogram_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurehistogram.v1.DeleteFeatureHistogramResponse)
  })
_sym_db.RegisterMessage(DeleteFeatureHistogramResponse)


DESCRIPTOR._options = None
_LISTFEATUREHISTOGRAMSREQUEST_LABELSENTRY._options = None

_FEATUREHISTOGRAMSERVICE = _descriptor.ServiceDescriptor(
  name='FeatureHistogramService',
  full_name='github.com.metaprov.modelaapi.services.featurehistogram.v1.FeatureHistogramService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1188,
  serialized_end=2423,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListFeatureHistograms',
    full_name='github.com.metaprov.modelaapi.services.featurehistogram.v1.FeatureHistogramService.ListFeatureHistograms',
    index=0,
    containing_service=None,
    input_type=_LISTFEATUREHISTOGRAMSREQUEST,
    output_type=_LISTFEATUREHISTOGRAMSRESPONSE,
    serialized_options=b'\202\323\344\223\002\027\022\025/v1/featurehistograms',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateFeatureHistogram',
    full_name='github.com.metaprov.modelaapi.services.featurehistogram.v1.FeatureHistogramService.CreateFeatureHistogram',
    index=1,
    containing_service=None,
    input_type=_CREATEFEATUREHISTOGRAMREQUEST,
    output_type=_CREATEFEATUREHISTOGRAMRESPONSE,
    serialized_options=b'\202\323\344\223\002\032\"\025/v1/featurehistograms:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFeatureHistogram',
    full_name='github.com.metaprov.modelaapi.services.featurehistogram.v1.FeatureHistogramService.GetFeatureHistogram',
    index=2,
    containing_service=None,
    input_type=_GETFEATUREHISTOGRAMREQUEST,
    output_type=_GETFEATUREHISTOGRAMRESPONSE,
    serialized_options=b'\202\323\344\223\002\036\022\034/v1/featurehistograms/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeatureHistogram',
    full_name='github.com.metaprov.modelaapi.services.featurehistogram.v1.FeatureHistogramService.UpdateFeatureHistogram',
    index=3,
    containing_service=None,
    input_type=_UPDATEFEATUREHISTOGRAMREQUEST,
    output_type=_UPDATEFEATUREHISTOGRAMRESPONSE,
    serialized_options=b'\202\323\344\223\002;\0326/v1/featurehistograms/{featurehistogram.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteFeatureHistogram',
    full_name='github.com.metaprov.modelaapi.services.featurehistogram.v1.FeatureHistogramService.DeleteFeatureHistogram',
    index=4,
    containing_service=None,
    input_type=_DELETEFEATUREHISTOGRAMREQUEST,
    output_type=_DELETEFEATUREHISTOGRAMRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_FEATUREHISTOGRAMSERVICE)

DESCRIPTOR.services_by_name['FeatureHistogramService'] = _FEATUREHISTOGRAMSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/license/v1/license.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/license/v1/license.proto',
  package='github.com.metaprov.modelaapi.services.license.v1',
  syntax='proto3',
  serialized_options=b'Z1github.com/metaprov/modelaapi/services/license/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n?github.com/metaprov/modelaapi/services/license/v1/license.proto\x12\x31github.com.metaprov.modelaapi.services.license.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\xbb\x01\n\x13ListLicensesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x62\n\x06labels\x18\x03 \x03(\x0b\x32R.github.com.metaprov.modelaapi.services.license.v1.ListLicensesRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"i\n\x14ListLicensesResponse\x12Q\n\x05items\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.LicenseList\"\x11\n\x0fLicenseResponse\"d\n\x14\x43reateLicenseRequest\x12L\n\x04item\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.License\"*\n\x1b\x43reateLicenseFromKeyRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\"\x17\n\x15\x43reateLicenseResponse\"d\n\x14UpdateLicenseRequest\x12L\n\x04item\x18\x05 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.License\"\x17\n\x15UpdateLicenseResponse\"4\n\x11GetLicenseRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"s\n\x12GetLicenseResponse\x12O\n\x07license\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.License\x12\x0c\n\x04yaml\x18\x02 \x01(\t\">\n\x1bGetLicenseNamespacesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"s\n\x1cGetLicenseNamespacesResponse\x12S\n\nnamespaces\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo\"7\n\x14\x44\x65leteLicenseRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x17\n\x15\x44\x65leteLicenseResponse2\xb1\t\n\x0eLicenseService\x12\xb4\x01\n\x0cListLicenses\x12\x46.github.com.metaprov.modelaapi.services.license.v1.ListLicensesRequest\x1aG.github.com.metaprov.modelaapi.services.license.v1.ListLicensesResponse\"\x13\x82\xd3\xe4\x93\x02\r\x12\x0bv1/licenses\x12\xbb\x01\n\rCreateLicense\x12G.github.com.metaprov.modelaapi.services.license.v1.CreateLicenseRequest\x1aH.github.com.metaprov.modelaapi.services.license.v1.CreateLicenseResponse\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0c/v1/licenses:\x01*\x12\xc9\x01\n\x14\x43reateLicenseFromKey\x12N.github.com.metaprov.modelaapi.services.license.v1.CreateLicenseFromKeyRequest\x1aH.github.com.metaprov.modelaapi.services.license.v1.CreateLicenseResponse\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0c/v1/licenses:\x01*\x12\xc6\x01\n\nGetLicense\x12\x44.github.com.metaprov.modelaapi.services.license.v1.GetLicenseRequest\x1a\x45.github.com.metaprov.modelaapi.services.license.v1.GetLicenseResponse\"+\x82\xd3\xe4\x93\x02%\x12#v1/licenses/{license.metadata.name}\x12\xca\x01\n\rUpdateLicense\x12G.github.com.metaprov.modelaapi.services.license.v1.UpdateLicenseRequest\x1aH.github.com.metaprov.modelaapi.services.license.v1.UpdateLicenseResponse\"&\x82\xd3\xe4\x93\x02 \x1a\x1b/v1/licenses/{license_name}:\x01*\x12\xc7\x01\n\rDeleteLicense\x12G.github.com.metaprov.modelaapi.services.license.v1.DeleteLicenseRequest\x1aH.github.com.metaprov.modelaapi.services.license.v1.DeleteLicenseResponse\"#\x82\xd3\xe4\x93\x02\x1d*\x1b/v1/licenses/{license_name}B3Z1github.com/metaprov/modelaapi/services/license/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2.DESCRIPTOR,])




_LISTLICENSESREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.license.v1.ListLicensesRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.license.v1.ListLicensesRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.license.v1.ListLicensesRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=425,
  serialized_end=470,
)

_LISTLICENSESREQUEST = _descriptor.Descriptor(
  name='ListLicensesRequest',
  full_name='github.com.metaprov.modelaapi.services.license.v1.ListLicensesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.license.v1.ListLicensesRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.license.v1.ListLicensesRequest.labels', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTLICENSESREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=283,
  serialized_end=470,
)


_LISTLICENSESRESPONSE = _descriptor.Descriptor(
  name='ListLicensesResponse',
  full_name='github.com.metaprov.modelaapi.services.license.v1.ListLicensesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.license.v1.ListLicensesResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=472,
  serialized_end=577,
)


_LICENSERESPONSE = _descriptor.Descriptor(
  name='LicenseResponse',
  full_name='github.com.metaprov.modelaapi.services.license.v1.LicenseResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=579,
  serialized_end=596,
)


_CREATELICENSEREQUEST = _descriptor.Descriptor(
  name='CreateLicenseRequest',
  full_name='github.com.metaprov.modelaapi.services.license.v1.CreateLicenseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.license.v1.CreateLicenseRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=598,
  serialized_end=698,
)


_CREATELICENSEFROMKEYREQUEST = _descriptor.Descriptor(
  name='CreateLicenseFromKeyRequest',
  full_name='github.com.metaprov.modelaapi.services.license.v1.CreateLicenseFromKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.license.v1.CreateLicenseFromKeyRequest.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=700,
  serialized_end=742,
)


_CREATELICENSERESPONSE = _descriptor.Descriptor(
  name='CreateLicenseResponse',
  full_name='github.com.metaprov.modelaapi.services.license.v1.CreateLicenseResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=744,
  serialized_end=767,
)


_UPDATELICENSEREQUEST = _descriptor.Descriptor(
  name='UpdateLicenseRequest',
  full_name='github.com.metaprov.modelaapi.services.license.v1.UpdateLicenseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.license.v1.UpdateLicenseRequest.item', index=0,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=769,
  serialized_end=869,
)


_UPDATELICENSERESPONSE = _descriptor.Descriptor(
  name='UpdateLicenseResponse',
  full_name='github.com.metaprov.modelaapi.services.license.v1.UpdateLicenseResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=871,
  serialized_end=894,
)


_GETLICENSEREQUEST = _descriptor.Descriptor(
  name='GetLicenseRequest',
  full_name='github.com.metaprov.modelaapi.services.license.v1.GetLicenseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.license.v1.GetLicenseRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.license.v1.GetLicenseRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=896,
  serialized_end=948,
)


_GETLICENSERESPONSE = _descriptor.Descriptor(
  name='GetLicenseResponse',
  full_name='github.com.metaprov.modelaapi.services.license.v1.GetLicenseResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='license', full_name='github.com.metaprov.modelaapi.services.license.v1.GetLicenseResponse.license', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.license.v1.GetLicenseResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=950,
  serialized_end=1065,
)


_GETLICENSENAMESPACESREQUEST = _descriptor.Descriptor(
  name='GetLicenseNamespacesRequest',
  full_name='github.com.metaprov.modelaapi.services.license.v1.GetLicenseNamespacesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.license.v1.GetLicenseNamespacesRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.license.v1.GetLicenseNamespacesRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1067,
  serialized_end=1129,
)


_GETLICENSENAMESPACESRESPONSE = _descriptor.Descriptor(
  name='GetLicenseNamespacesResponse',
  full_name='github.com.metaprov.modelaapi.services.license.v1.GetLicenseNamespacesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespaces', full_name='github.com.metaprov.modelaapi.services.license.v1.GetLicenseNamespacesResponse.namespaces', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1131,
  serialized_end=1246,
)


_DELETELICENSEREQUEST = _descriptor.Descriptor(
  name='DeleteLicenseRequest',
  full_name='github.com.metaprov.modelaapi.services.license.v1.DeleteLicenseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.license.v1.DeleteLicenseRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.license.v1.DeleteLicenseRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1248,
  serialized_end=1303,
)


_DELETELICENSERESPONSE = _descriptor.Descriptor(
  name='DeleteLicenseResponse',
  full_name='github.com.metaprov.modelaapi.services.license.v1.DeleteLicenseResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1305,
  serialized_end=1328,
)

_LISTLICENSESREQUEST_LABELSENTRY.containing_type = _LISTLICENSESREQUEST
_LISTLICENSESREQUEST.fields_by_name['labels'].message_type = _LISTLICENSESREQUEST_LABELSENTRY
_LISTLICENSESRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._LICENSELIST
_CREATELICENSEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._LICENSE
_UPDATELICENSEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._LICENSE
_GETLICENSERESPONSE.fields_by_name['license'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._LICENSE
_GETLICENSENAMESPACESRESPONSE.fields_by_name['namespaces'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2._NAMESPACEINFO
DESCRIPTOR.message_types_by_name['ListLicensesRequest'] = _LISTLICENSESREQUEST
DESCRIPTOR.message_types_by_name['ListLicensesResponse'] = _LISTLICENSESRESPONSE
DESCRIPTOR.message_types_by_name['LicenseResponse'] = _LICENSERESPONSE
DESCRIPTOR.message_types_by_name['CreateLicenseRequest'] = _CREATELICENSEREQUEST
DESCRIPTOR.message_types_by_name['CreateLicenseFromKeyRequest'] = _CREATELICENSEFROMKEYREQUEST
DESCRIPTOR.message_types_by_name['CreateLicenseResponse'] = _CREATELICENSERESPONSE
DESCRIPTOR.message_types_by_name['UpdateLicenseRequest'] = _UPDATELICENSEREQUEST
DESCRIPTOR.message_types_by_name['UpdateLicenseResponse'] = _UPDATELICENSERESPONSE
DESCRIPTOR.message_types_by_name['GetLicenseRequest'] = _GETLICENSEREQUEST
DESCRIPTOR.message_types_by_name['GetLicenseResponse'] = _GETLICENSERESPONSE
DESCRIPTOR.message_types_by_name['GetLicenseNamespacesRequest'] = _GETLICENSENAMESPACESREQUEST
DESCRIPTOR.message_types_by_name['GetLicenseNamespacesResponse'] = _GETLICENSENAMESPACESRESPONSE
DESCRIPTOR.message_types_by_name['DeleteLicenseRequest'] = _DELETELICENSEREQUEST
DESCRIPTOR.message_types_by_name['DeleteLicenseResponse'] = _DELETELICENSERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListLicensesRequest = _reflection.GeneratedProtocolMessageType('ListLicensesRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTLICENSESREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.license.v1.license_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.license.v1.ListLicensesRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTLICENSESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.license.v1.license_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.license.v1.ListLicensesRequest)
  })
_sym_db.RegisterMessage(ListLicensesRequest)
_sym_db.RegisterMessage(ListLicensesRequest.LabelsEntry)

ListLicensesResponse = _reflection.GeneratedProtocolMessageType('ListLicensesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLICENSESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.license.v1.license_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.license.v1.ListLicensesResponse)
  })
_sym_db.RegisterMessage(ListLicensesResponse)

LicenseResponse = _reflection.GeneratedProtocolMessageType('LicenseResponse', (_message.Message,), {
  'DESCRIPTOR' : _LICENSERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.license.v1.license_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.license.v1.LicenseResponse)
  })
_sym_db.RegisterMessage(LicenseResponse)

CreateLicenseRequest = _reflection.GeneratedProtocolMessageType('CreateLicenseRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATELICENSEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.license.v1.license_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.license.v1.CreateLicenseRequest)
  })
_sym_db.RegisterMessage(CreateLicenseRequest)

CreateLicenseFromKeyRequest = _reflection.GeneratedProtocolMessageType('CreateLicenseFromKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATELICENSEFROMKEYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.license.v1.license_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.license.v1.CreateLicenseFromKeyRequest)
  })
_sym_db.RegisterMessage(CreateLicenseFromKeyRequest)

CreateLicenseResponse = _reflection.GeneratedProtocolMessageType('CreateLicenseResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATELICENSERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.license.v1.license_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.license.v1.CreateLicenseResponse)
  })
_sym_db.RegisterMessage(CreateLicenseResponse)

UpdateLicenseRequest = _reflection.GeneratedProtocolMessageType('UpdateLicenseRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELICENSEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.license.v1.license_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.license.v1.UpdateLicenseRequest)
  })
_sym_db.RegisterMessage(UpdateLicenseRequest)

UpdateLicenseResponse = _reflection.GeneratedProtocolMessageType('UpdateLicenseResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELICENSERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.license.v1.license_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.license.v1.UpdateLicenseResponse)
  })
_sym_db.RegisterMessage(UpdateLicenseResponse)

GetLicenseRequest = _reflection.GeneratedProtocolMessageType('GetLicenseRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLICENSEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.license.v1.license_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.license.v1.GetLicenseRequest)
  })
_sym_db.RegisterMessage(GetLicenseRequest)

GetLicenseResponse = _reflection.GeneratedProtocolMessageType('GetLicenseResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLICENSERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.license.v1.license_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.license.v1.GetLicenseResponse)
  })
_sym_db.RegisterMessage(GetLicenseResponse)

GetLicenseNamespacesRequest = _reflection.GeneratedProtocolMessageType('GetLicenseNamespacesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLICENSENAMESPACESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.license.v1.license_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.license.v1.GetLicenseNamespacesRequest)
  })
_sym_db.RegisterMessage(GetLicenseNamespacesRequest)

GetLicenseNamespacesResponse = _reflection.GeneratedProtocolMessageType('GetLicenseNamespacesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLICENSENAMESPACESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.license.v1.license_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.license.v1.GetLicenseNamespacesResponse)
  })
_sym_db.RegisterMessage(GetLicenseNamespacesResponse)

DeleteLicenseRequest = _reflection.GeneratedProtocolMessageType('DeleteLicenseRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETELICENSEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.license.v1.license_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.license.v1.DeleteLicenseRequest)
  })
_sym_db.RegisterMessage(DeleteLicenseRequest)

DeleteLicenseResponse = _reflection.GeneratedProtocolMessageType('DeleteLicenseResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETELICENSERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.license.v1.license_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.license.v1.DeleteLicenseResponse)
  })
_sym_db.RegisterMessage(DeleteLicenseResponse)


DESCRIPTOR._options = None
_LISTLICENSESREQUEST_LABELSENTRY._options = None

_LICENSESERVICE = _descriptor.ServiceDescriptor(
  name='LicenseService',
  full_name='github.com.metaprov.modelaapi.services.license.v1.LicenseService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1331,
  serialized_end=2532,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListLicenses',
    full_name='github.com.metaprov.modelaapi.services.license.v1.LicenseService.ListLicenses',
    index=0,
    containing_service=None,
    input_type=_LISTLICENSESREQUEST,
    output_type=_LISTLICENSESRESPONSE,
    serialized_options=b'\202\323\344\223\002\r\022\013v1/licenses',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateLicense',
    full_name='github.com.metaprov.modelaapi.services.license.v1.LicenseService.CreateLicense',
    index=1,
    containing_service=None,
    input_type=_CREATELICENSEREQUEST,
    output_type=_CREATELICENSERESPONSE,
    serialized_options=b'\202\323\344\223\002\021\"\014/v1/licenses:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateLicenseFromKey',
    full_name='github.com.metaprov.modelaapi.services.license.v1.LicenseService.CreateLicenseFromKey',
    index=2,
    containing_service=None,
    input_type=_CREATELICENSEFROMKEYREQUEST,
    output_type=_CREATELICENSERESPONSE,
    serialized_options=b'\202\323\344\223\002\021\"\014/v1/licenses:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetLicense',
    full_name='github.com.metaprov.modelaapi.services.license.v1.LicenseService.GetLicense',
    index=3,
    containing_service=None,
    input_type=_GETLICENSEREQUEST,
    output_type=_GETLICENSERESPONSE,
    serialized_options=b'\202\323\344\223\002%\022#v1/licenses/{license.metadata.name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateLicense',
    full_name='github.com.metaprov.modelaapi.services.license.v1.LicenseService.UpdateLicense',
    index=4,
    containing_service=None,
    input_type=_UPDATELICENSEREQUEST,
    output_type=_UPDATELICENSERESPONSE,
    serialized_options=b'\202\323\344\223\002 \032\033/v1/licenses/{license_name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteLicense',
    full_name='github.com.metaprov.modelaapi.services.license.v1.LicenseService.DeleteLicense',
    index=5,
    containing_service=None,
    input_type=_DELETELICENSEREQUEST,
    output_type=_DELETELICENSERESPONSE,
    serialized_options=b'\202\323\344\223\002\035*\033/v1/licenses/{license_name}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_LICENSESERVICE)

DESCRIPTOR.services_by_name['LicenseService'] = _LICENSESERVICE

# @@protoc_insertion_point(module_scope)
